RankBasedMetric
===============

.. currentmodule:: pykeen.metrics

.. autoclass:: RankBasedMetric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~RankBasedMetric.binarize
      ~RankBasedMetric.closed_expectation
      ~RankBasedMetric.closed_variance
      ~RankBasedMetric.key
      ~RankBasedMetric.needs_candidates
      ~RankBasedMetric.supported_rank_types
      ~RankBasedMetric.supports_weights
      ~RankBasedMetric.synonyms

   .. rubric:: Methods Summary

   .. autosummary::

      ~RankBasedMetric.__call__
      ~RankBasedMetric.expected_value
      ~RankBasedMetric.extra_repr
      ~RankBasedMetric.get_description
      ~RankBasedMetric.get_link
      ~RankBasedMetric.get_range
      ~RankBasedMetric.get_sampled_values
      ~RankBasedMetric.iter_extra_repr
      ~RankBasedMetric.numeric_expected_value
      ~RankBasedMetric.numeric_expected_value_with_ci
      ~RankBasedMetric.numeric_variance
      ~RankBasedMetric.numeric_variance_with_ci
      ~RankBasedMetric.std
      ~RankBasedMetric.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: key
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: expected_value
   .. automethod:: extra_repr
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: get_sampled_values
   .. automethod:: iter_extra_repr
   .. automethod:: numeric_expected_value
   .. automethod:: numeric_expected_value_with_ci
   .. automethod:: numeric_variance
   .. automethod:: numeric_variance_with_ci
   .. automethod:: std
   .. automethod:: variance
